@@ -208,11 +208,8 @@ Frame_Glom::~Frame_Glom()
   if(m_pBox_Tables)
     remove_view(m_pBox_Tables);
 
-  if(m_pDialog_Tables)
-  {
-    delete m_pDialog_Tables;
-    m_pDialog_Tables = 0;
-  }
+  delete m_pDialog_Tables;
+  m_pDialog_Tables = 0;
 #endif //GLOM_ENABLE_MAEMO
 
   remove_view(&m_Notebook_Data); //Also a composite view.
@@ -227,24 +224,15 @@ Frame_Glom::~Frame_Glom()
   }
 
 
-  if(m_dialog_progess_connection_startup)
-  {
-    delete m_dialog_progess_connection_startup;
-    m_dialog_progess_connection_startup = 0;
-  }
+  delete m_dialog_progess_connection_startup;
+  m_dialog_progess_connection_startup = 0;
 
-  if(m_dialog_progess_connection_cleanup)
-  {
-    delete m_dialog_progess_connection_cleanup;
-    m_dialog_progess_connection_cleanup = 0;
-  }
+  delete m_dialog_progess_connection_cleanup;
+  m_dialog_progess_connection_cleanup = 0;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  if(m_dialog_progess_connection_initialize)
-  {
-    delete m_dialog_progess_connection_initialize;
-    m_dialog_progess_connection_initialize = 0;
-  }
+  delete m_dialog_progess_connection_initialize;
+  m_dialog_progess_connection_initialize = 0;
 
   if(m_pBox_Reports)
     remove_view(m_pBox_Reports);
@@ -727,58 +715,6 @@ void Frame_Glom::export_data_to_vector(Document::type_example_rows& the_vector,
   }
 }
 
-void Frame_Glom::export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document::type_list_layout_groups& sequence)
-{
-  type_vecConstLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
-
-  if(fieldsSequence.empty())
-  {
-    std::cerr << G_STRFUNC << ": No fields in sequence." << std::endl;
-    return;
-  }
-
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsSequence, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause);
-
-  //TODO: Lock the database (prevent changes) during export.
-  Glib::RefPtr<const Gnome::Gda::DataModel> result = DbUtils::query_execute_select(query);
-
-  guint rows_count = 0;
-  if(result)
-    rows_count = result->get_n_rows();
-
-  if(rows_count)
-  {
-    const guint columns_count = result->get_n_columns();
-
-    for(guint row_index = 0; row_index < rows_count; ++row_index)
-    {
-        std::string row_string;
-
-        for(guint col_index = 0; col_index < columns_count; ++col_index)
-        {
-          const Gnome::Gda::Value value = result->get_value_at(col_index, row_index);
-
-          sharedptr<const LayoutItem_Field> layout_item = fieldsSequence[col_index];
-          //if(layout_item->m_field.get_glom_type() != Field::TYPE_IMAGE) //This is too much data.
-          //{
-            if(!row_string.empty())
-              row_string += ',';
-
-            //Output data in canonical SQL format, ignoring the user's locale, and ignoring the layout formatting:
-            row_string += layout_item->get_full_field_details()->to_file_format(value);
-
-            //if(layout_item->m_field.get_glom_type() == Field::TYPE_IMAGE) //This is too much data.
-            //{
-             //std::cout << "  field name=" << layout_item->get_name() << ", value=" << layout_item->m_field.sql(value) << std::endl;
-            //}
-        }
-
-        //std::cout << " row_string=" << row_string << std::endl;
-        the_string += (row_string += "\n");
-    }
-  }
-}
-
 void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document::type_list_layout_groups& sequence)
 {
   type_vecConstLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
@@ -1111,11 +1047,8 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
 
     connectionpool->cleanup( sigc::mem_fun(*this, &Frame_Glom::on_connection_cleanup_progress) );
 
-    if(m_dialog_progess_connection_cleanup)
-    {
-      delete m_dialog_progess_connection_cleanup;
-      m_dialog_progess_connection_cleanup = 0;
-    }
+    delete m_dialog_progess_connection_cleanup;
+    m_dialog_progess_connection_cleanup = 0;
 
     connectionpool->set_network_shared(sigc::mem_fun(*this, &Frame_Glom::on_connection_startup_progress), shared);
     ConnectionPool::StartupErrors started = connectionpool->startup( sigc::mem_fun(*this, &Frame_Glom::on_connection_startup_progress) );
@@ -1127,11 +1060,8 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
 
     connectionpool->set_ready_to_connect();
 
-    if(m_dialog_progess_connection_startup)
-    {
-      delete m_dialog_progess_connection_startup;
-      m_dialog_progess_connection_startup = 0;
-    }
+    delete m_dialog_progess_connection_startup;
+    m_dialog_progess_connection_startup = 0;
   }
 
   //Update the UI:
@@ -1225,11 +1155,6 @@ void Frame_Glom::on_menu_Reports_EditReports()
   on_menu_developer_reports();
 }
 
-void Frame_Glom::on_menu_File_EditPrintLayouts()
-{
-  on_menu_developer_print_layouts();
-}
-
 void Frame_Glom::on_menu_Tables_EditTables()
 {
   do_menu_Navigate_Table();
@@ -2099,11 +2024,8 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
       const bool initialized = handle_connection_initialize_errors( connection_pool->initialize(
         sigc::mem_fun(*this, &Frame_Glom::on_connection_initialize_progress) ) );
 
-      if(m_dialog_progess_connection_initialize)
-      {
-        delete m_dialog_progess_connection_initialize;
-        m_dialog_progess_connection_initialize = 0;
-      }
+      delete m_dialog_progess_connection_initialize;
+      m_dialog_progess_connection_initialize = 0;
 
       if(!initialized)
         return false;
@@ -2178,11 +2100,8 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     return false;
   }
 
-  if(m_dialog_progess_connection_startup)
-  {
-    delete m_dialog_progess_connection_startup;
-    m_dialog_progess_connection_startup = 0;
-  }
+  delete m_dialog_progess_connection_startup;
+  m_dialog_progess_connection_startup = 0;
 
   const Glib::ustring database_name = document->get_connection_database();
 
@@ -2288,11 +2207,8 @@ void Frame_Glom::cleanup_connection()
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   connection_pool->cleanup( sigc::mem_fun(*this, &Frame_Glom::on_connection_cleanup_progress) );
 
-  if(m_dialog_progess_connection_cleanup)
-  {
-    delete m_dialog_progess_connection_cleanup;
-    m_dialog_progess_connection_cleanup = 0;
-  }
+  delete m_dialog_progess_connection_cleanup;
+  m_dialog_progess_connection_cleanup = 0;
 }
 
 bool Frame_Glom::handle_request_password_connection_error(bool asked_for_password, const ExceptionConnection& ex, bool& database_not_found)
@@ -2346,11 +2262,8 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
     return false;
   }
 
-  if(m_dialog_progess_connection_startup)
-  {
-    delete m_dialog_progess_connection_startup;
-    m_dialog_progess_connection_startup = 0;
-  }
+  delete m_dialog_progess_connection_startup;
+  m_dialog_progess_connection_startup = 0;
 
   //Only ask for the password if we are shared on the network, or we are using a centrally hosted server.
   //Otherwise, no password question is necessary, due to how our self-hosted database server is configured.
@@ -2358,11 +2271,8 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
     || document->get_hosting_mode() == Document::HOSTING_MODE_POSTGRES_CENTRAL)
   {
     //We recreate the dialog each time to make sure it is clean of any changes:
-    if(m_pDialogConnection)
-    {
-      delete m_pDialogConnection;
-      m_pDialogConnection = 0;
-    }
+    delete m_pDialogConnection;
+    m_pDialogConnection = 0;
 
     Utils::get_glade_widget_derived_with_warning(m_pDialogConnection);
     add_view(m_pDialogConnection); //Also a composite view.
@@ -2380,7 +2290,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
     if(!known_password.empty())
       m_pDialogConnection->set_password(known_password);
   }
-  else if(m_pDialogConnection)
+  else
   {
     //Later, if m_pDialogConnection is null then we assume we should use the known user/password:
     delete m_pDialogConnection;
@@ -2610,22 +2520,6 @@ void Frame_Glom::on_dialog_layout_print_hide()
   if(pApp)
     pApp->fill_menu_print_layouts(m_table_name);
 }
-
-void Frame_Glom::on_dialog_reports_hide()
-{
-  //Update the reports menu:
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
-  if(pApp)
-    pApp->fill_menu_reports(m_table_name);
-}
-
-void Frame_Glom::on_dialog_print_layouts_hide()
-{
-  //Update the reports menu:
-  Application* pApp = dynamic_cast<Application*>(get_app_window());
-  if(pApp)
-    pApp->fill_menu_print_layouts(m_table_name);
-}
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 void Frame_Glom::on_dialog_tables_hide()
