@@ -18,20 +18,20 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef BOX_DATA_LIST_H
-#define BOX_DATA_LIST_H
+#ifndef GLOM_MODE_DATA_BOX_DATA_LIST_H
+#define GLOM_MODE_DATA_BOX_DATA_LIST_H
 
 #include "config.h" // GLOM_ENABLE_CLIENT_ONLY
 
 #include "box_data_manyrecords.h"
-#include <glom/utility_widgets/db_adddel/db_adddel_withbuttons.h>
+#include <glom/mode_data/db_adddel/db_adddel_withbuttons.h>
 
 namespace Glom
 {
 
 class Box_Data_List : public Box_Data_ManyRecords
 {
-public: 
+public:
   Box_Data_List();
   virtual ~Box_Data_List();
 
@@ -83,8 +83,7 @@ protected:
   //Overrides of functions from Box_Data:
   virtual void create_layout(); //override
   virtual Document::type_list_layout_groups create_layout_get_layout();
-  void create_layout_add_group(const sharedptr<LayoutGroup>& layout_group);
-    
+
   virtual bool fill_from_database(); //override.
   virtual void enable_buttons();
 
@@ -120,4 +119,4 @@ protected:
 
 } //namespace Glom
 
-#endif
+#endif // GLOM_MODE_DATA_BOX_DATA_LIST_H
