@@ -18,14 +18,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef DIALOG_FIELDDEFINITION_H
-#define DIALOG_FIELDDEFINITION_H
+#ifndef GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
+#define GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
 
-#include <gtkmm/dialog.h>
-#include <gtkmm/checkbutton.h>
-#include <gtkmm/alignment.h>
-#include <gtkmm/entry.h>
-#include <gtkmm/table.h>
+#include <gtkmm.h>
 #include "../../utility_widgets/combo_textglade.h"
 #include <glom/mode_design/layout/combobox_relationship.h>
 #include "combo_fieldtype.h"
@@ -35,7 +31,7 @@
 #include <libglom/data_structure/field.h>
 #include <glom/mode_design/layout/layout_item_dialogs/box_formatting.h>
 #include <glom/base_db.h>
-#include <gtksourceviewmm/sourceview.h>
+#include <gtksourceviewmm/view.h>
 
 namespace Glom
 {
@@ -88,7 +84,7 @@ private:
 
   Gtk::RadioButton* m_pRadio_Calculate;
   Gtk::Alignment* m_pAlignment_Calculate;
-  gtksourceview::SourceView* m_pTextView_Calculation;
+  Gsv::View* m_pTextView_Calculation;
   Gtk::Button* m_pButton_EditCalculation;
 
   Gtk::Entry* m_pEntry_Title;
@@ -104,4 +100,4 @@ private:
 
 } //namespace Glom
 
-#endif //DIALOG_FIELDDEFINITION_H
+#endif // GLOM_MODE_DESIGN_DIALOG_FIELDDEFINITION_H
