@@ -25,9 +25,8 @@
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h>
 #include <glom/mode_design/script_library/dialog_new_script.h>
-#include <gtksourceviewmm/sourcelanguagemanager.h>
+#include <gtksourceviewmm/languagemanager.h>
 #include <glom/application.h>
-#include <gtkmm/stock.h>
 
 
 //#include <libgnome/gnome-i18n.h>
@@ -59,13 +58,13 @@ Dialog_ScriptLibrary::Dialog_ScriptLibrary(BaseObjectType* cobject, const Glib::
   //Dialog_Properties::set_modified(false);
 
   //Set the SourceView to do syntax highlighting for Python:
-  Glib::RefPtr<gtksourceview::SourceLanguageManager> languages_manager = gtksourceview::SourceLanguageManager::get_default();
+  Glib::RefPtr<Gsv::LanguageManager> languages_manager = Gsv::LanguageManager::get_default();
 
-  Glib::RefPtr<gtksourceview::SourceLanguage> language = languages_manager->get_language("python"); //This is the GtkSourceView language ID.
+  Glib::RefPtr<Gsv::Language> language = languages_manager->get_language("python"); //This is the GtkSourceView language ID.
   if(language)
   {
      //Create a new buffer and set it, instead of getting the default buffer, in case libglade has tried to set it, using the wrong buffer type:
-     Glib::RefPtr<gtksourceview::SourceBuffer> buffer = gtksourceview::SourceBuffer::create(language);
+     Glib::RefPtr<Gsv::Buffer> buffer = Gsv::Buffer::create(language);
      buffer->set_highlight_syntax();
      m_text_view->set_buffer(buffer);
   }
@@ -95,6 +94,9 @@ void Dialog_ScriptLibrary::on_button_add()
 
   Dialog_NewScript* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return;
+    
   dialog->set_transient_for(*this);
   const int response = Glom::Utils::dialog_run_with_help(dialog);
   dialog->hide();
